@@ -24,13 +24,6 @@ def test_validate_email():
     ),
 )
 def test_Client():
-    kwargs = {"host": "localhost"}
-    spec = Client(**kwargs).swagger_spec
-    assert spec.http_client.headers == {}
-    assert spec.origin_url == "http://localhost/apispec.json"
-    assert spec.spec_dict["host"] == "localhost"
-    assert spec.spec_dict["schemes"] == ["http"]
-    assert spec.user_defined_formats["email"] == email_format
     kwargs = {"apikey": "1234"}
     spec = Client(**kwargs).swagger_spec
     assert spec.http_client.headers == {"x-api-key": "1234"}
